@@ -1,7 +1,6 @@
-from scipy import ndimage as ndi
 import numpy as np
 from typing import List
-from scipy.ndimage.filters import gaussian_laplace
+from scipy.ndimage import gaussian_laplace
 
 
 def dot_3d(struct_img: np.ndarray, log_sigma: float, cutoff=-1):
@@ -21,7 +20,7 @@ def dot_3d(struct_img: np.ndarray, log_sigma: float, cutoff=-1):
         negative, no cutoff will be applied. Default is -1
     """
     assert len(struct_img.shape) == 3
-    responce = -1 * (log_sigma ** 2) * ndi.filters.gaussian_laplace(struct_img, log_sigma)
+    responce = -1 * (log_sigma**2) * gaussian_laplace(struct_img, log_sigma)
     if cutoff < 0:
         return responce
     else:
@@ -45,7 +44,7 @@ def dot_2d(struct_img, log_sigma, cutoff=-1):
         negative, no cutoff will be applied. Default is -1
     """
     assert len(struct_img.shape) == 2
-    responce = -1 * (log_sigma ** 2) * ndi.filters.gaussian_laplace(struct_img, log_sigma)
+    responce = -1 * (log_sigma**2) * gaussian_laplace(struct_img, log_sigma)
     if cutoff < 0:
         return responce
     else:
@@ -74,7 +73,7 @@ def dot_3d_wrapper(struct_img: np.ndarray, s3_param: List):
     bw = np.zeros(struct_img.shape, dtype=bool)
     for fid in range(len(s3_param)):
         log_sigma = s3_param[fid][0]
-        responce = -1 * (log_sigma ** 2) * ndi.filters.gaussian_laplace(struct_img, log_sigma)
+        responce = -1 * (log_sigma**2) * gaussian_laplace(struct_img, log_sigma)
         bw = np.logical_or(bw, responce > s3_param[fid][1])
     return bw
 
@@ -92,7 +91,7 @@ def logSlice(image: np.ndarray, sigma_list: List, threshold: float):
         the cutoff to apply to get the binary output
     """
 
-    gl_images = [-gaussian_laplace(image, s) * (s ** 2) for s in sigma_list]
+    gl_images = [-gaussian_laplace(image, s) * (s**2) for s in sigma_list]
 
     # get the mask
     seg = np.zeros_like(image)
@@ -120,7 +119,7 @@ def dot_slice_by_slice(struct_img: np.ndarray, log_sigma: float, cutoff=-1):
     """
     res = np.zeros_like(struct_img)
     for zz in range(struct_img.shape[0]):
-        res[zz, :, :] = -1 * (log_sigma ** 2) * ndi.filters.gaussian_laplace(struct_img[zz, :, :], log_sigma)
+        res[zz, :, :] = -1 * (log_sigma**2) * gaussian_laplace(struct_img[zz, :, :], log_sigma)
 
     if cutoff < 0:
         return res
@@ -152,6 +151,6 @@ def dot_2d_slice_by_slice_wrapper(struct_img: np.ndarray, s2_param: List):
         log_sigma = s2_param[fid][0]
         responce = np.zeros_like(struct_img)
         for zz in range(struct_img.shape[0]):
-            responce[zz, :, :] = -1 * (log_sigma ** 2) * ndi.filters.gaussian_laplace(struct_img[zz, :, :], log_sigma)
+            responce[zz, :, :] = -1 * (log_sigma**2) * gaussian_laplace(struct_img[zz, :, :], log_sigma)
         bw = np.logical_or(bw, responce > s2_param[fid][1])
     return bw
